@@ -162,6 +162,18 @@ class WorksheetTest(GspreadTest):
         super(WorksheetTest, cls).setUpClass()
         ss_id = cls.config.get('Spreadsheet', 'id')
         cls.spreadsheet = cls.gc.open_by_key(ss_id)
+        cls.spreadsheet.batch_update(
+            {
+                "requests": [
+                    {
+                        "updateSpreadsheetProperties": {
+                            "properties": {"locale": "en_US"},
+                            "fields": "locale",
+                        }
+                    }
+                ]
+            }
+        )
         try:
             test_sheet = cls.spreadsheet.worksheet('wksht_test')
             if test_sheet:
@@ -342,6 +354,12 @@ class WorksheetTest(GspreadTest):
         self.assertEqual(eff_rule.strict, None)
         self.assertEqual(eff_rule, boolean_validation_rule)
 
+    def test_boolean_condition(self):
+        with self.assertRaises(ValueError):
+            BooleanCondition('TEXT_EQ', 'foo')
+        with self.assertRaises(ValueError):
+            BooleanCondition('ONE_OF_LIST', 'foo')
+
     def test_conditional_format_rules(self):
         rows = [
             ["A", "B", "C", "D"],
@@ -357,7 +375,7 @@ class WorksheetTest(GspreadTest):
         new_rule = ConditionalFormatRule(
             ranges=[GridRange.from_a1_range('A1:D1', self.sheet)],
             booleanRule=BooleanRule(
-                condition=BooleanCondition('TEXT_CONTAINS', 'A'), 
+                condition=BooleanCondition('TEXT_CONTAINS', ['A']), 
                 format=CellFormat(textFormat=TextFormat(bold=True))
             )
         )
@@ -497,6 +515,14 @@ class WorksheetTest(GspreadTest):
         for col in col_md[0:1]:
             self.assertEqual(187, col['pixelSize'])
 
+    def test_batch_updater_different_spreadsheet(self):
+        batch = batch_updater(self.sheet.spreadsheet)
+        other_spread = gspread.Spreadsheet(None, {'id': 'blech', 'title': 'Other sheet'})
+        other_sheet = gspread.Worksheet(other_spread, {'sheetId': 4, 'title': 'Bleh'})
+        batch.set_row_height(self.sheet, '1:5', 42)
+        with self.assertRaises(ValueError):
+            batch.set_row_height(other_sheet, '1:5', 42)
+
     def test_batch_updater_context(self):
         batch = batch_updater(self.sheet.spreadsheet)
         batch.set_row_height(self.sheet, '1:5', 42)
@@ -535,3 +561,36 @@ class ColorTest(unittest.TestCase):
                 Color.fromHex(hexstring)
 
 
+class FormattingComponentTest(unittest.TestCase):
+
+    def test_repr_and_equality(self):
+        comp = TextFormat(bold=True, italic=True)
+        comp2 = TextFormat(bold=True)
+        self.assertEqual('<TextFormat bold=True;italic=True>', repr(comp))
+        self.assertNotEqual(comp, comp2)
+        self.assertNotEqual(comp, None)
+        self.assertEqual(comp, comp)
+
+    def test_number_format_types(self):
+        for type_ in NumberFormat.TYPES:
+            f = NumberFormat(type_)
+            self.assertEqual(f, f)
+            self.assertEqual(type_, f.type)
+        with self.assertRaises(ValueError):
+            NumberFormat('BAD_TYPE')
+
+    def test_border_styles(self):
+        for style in Border.STYLES:
+            f = Border(style)
+            self.assertEqual(f, f)
+            self.assertEqual(style, f.style)
+        with self.assertRaises(ValueError):
+            Border('BAD_STYLE')
+
+    def test_text_rotation_exclusion(self):
+        TextRotation(angle=1)
+        TextRotation(vertical=True)
+        with self.assertRaises(ValueError):
+            TextRotation(angle=1, vertical=True)
+        with self.assertRaises(ValueError):
+            TextRotation()
